@@ -1,9 +1,5 @@
-import json
-import os
-import time
 from time import sleep
 
-import requests
 from notecoin.huobi.client import GenericClient
 from notecoin.huobi.strategy.message import HuoBiMessage
 from notetool.tool.log import logger
@@ -77,6 +73,5 @@ class FindNewCoin:
 find = FindNewCoin()
 find.run()
 
-
 # ps -elf|grep check_new
 # nohup /root/anaconda3/bin/python3.8 /root/workspace/notechats/notecoin/notecoin/huobi/strategy/check_new.py >>/root/workspace/tmp/notecoin-check-run-$(date +%Y-%m-%d).log 2>&1 &
